summaryrefslogtreecommitdiffstats
path: root/lib/kformula/textelement.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit7c71ab86d1f7e387fc3df63b48df07231f111862 (patch)
tree30ba2d2f840ff5fd458b6113e9c3f2e8a71d510d /lib/kformula/textelement.cc
parentafbfdc507bfaafc8824a9808311d57a9ece87510 (diff)
downloadkoffice-7c71ab86d1f7e387fc3df63b48df07231f111862.tar.gz
koffice-7c71ab86d1f7e387fc3df63b48df07231f111862.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kformula/textelement.cc')
-rw-r--r--lib/kformula/textelement.cc64
1 files changed, 32 insertions, 32 deletions
diff --git a/lib/kformula/textelement.cc b/lib/kformula/textelement.cc
index 24eae2d8..c42a6e2f 100644
--- a/lib/kformula/textelement.cc
+++ b/lib/kformula/textelement.cc
@@ -106,7 +106,7 @@ bool TextElement::isInvisible() const
/**
* Calculates our width and height and
- * our tqchildren's tqparentPosition.
+ * our tqchildren's parentPosition.
*/
void TextElement::calcSizes( const ContextStyle& context,
ContextStyle::TextStyle tstyle,
@@ -120,7 +120,7 @@ void TextElement::calcSizes( const ContextStyle& context,
setCharFamily( style.charFamily() );
TQFont font = getFont( context, style );
- double fontsize = context.tqlayoutUnitPtToPt( mySize );
+ double fontsize = context.layoutUnitPtToPt( mySize );
double scriptsize = pow( style.scriptSizeMultiplier(), style.scriptLevel() );
double size = fontsize * scriptsize;
font.setPointSizeFloat( size < style.scriptMinSize() ? style.scriptMinSize() : size );
@@ -156,21 +156,21 @@ void TextElement::calcSizes( const ContextStyle& context,
/**
* Draws the whole element including its tqchildren.
* The `tqparentOrigin' is the point this element's tqparent starts.
* We can use our tqparentPosition to get our own origin then.
*/
void TextElement::draw( TQPainter& painter, const LuPixelRect& /*r*/,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle /*istyle*/,
StyleAttributes& style,
- const LuPixelPoint& tqparentOrigin )
+ const LuPixelPoint& parentOrigin )
{
if ( character == applyFunctionChar || character == invisibleTimes || character == invisibleComma ) {
return;
}
- LuPixelPoint myPos( tqparentOrigin.x()+getX(), tqparentOrigin.y()+getY() );
+ LuPixelPoint myPos( parentOrigin.x()+getX(), parentOrigin.y()+getY() );
//if ( !LuPixelRect( myPos.x(), myPos.y(), getWidth(), getHeight() ).intersects( r ) )
// return;
@@ -184,7 +184,7 @@ void TextElement::draw( TQPainter& painter, const LuPixelRect& /*r*/,
double factor = style.sizeFactor();
luPt mySize = context.getAdjustedSize( tstyle, factor );
TQFont font = getFont( context, style );
- double fontsize = context.tqlayoutUnitPtToPt( mySize );
+ double fontsize = context.layoutUnitPtToPt( mySize );
double scriptsize = pow( style.scriptSizeMultiplier(), style.scriptLevel() );
double size = fontsize * scriptsize;
font.setPointSizeFloat( size < style.scriptMinSize() ? style.scriptMinSize() : size );
@@ -192,7 +192,7 @@ void TextElement::draw( TQPainter& painter, const LuPixelRect& /*r*/,
//kdDebug( DEBUGID ) << "TextElement::draw font=" << font.rawName() << endl;
//kdDebug( DEBUGID ) << "TextElement::draw size=" << mySize << endl;
- //kdDebug( DEBUGID ) << "TextElement::draw size=" << context.tqlayoutUnitToFontSize( mySize, false ) << endl;
+ //kdDebug( DEBUGID ) << "TextElement::draw size=" << context.layoutUnitToFontSize( mySize, false ) << endl;
//kdDebug( DEBUGID ) << "TextElement::draw height: " << getHeight() << endl;
//kdDebug( DEBUGID ) << "TextElement::draw width: " << getWidth() << endl;
//kdDebug( DEBUGID ) << endl;
@@ -205,13 +205,13 @@ void TextElement::draw( TQPainter& painter, const LuPixelRect& /*r*/,
// kdDebug() << "draw text: " << text[0].tqunicode()
// << " " << painter.font().family().latin1()
// << endl;
- painter.fillRect( context.tqlayoutUnitToPixelX( tqparentOrigin.x() ),
- context.tqlayoutUnitToPixelY( tqparentOrigin.y() ),
- context.tqlayoutUnitToPixelX( getParent()->getWidth() ),
- context.tqlayoutUnitToPixelY( getParent()->getHeight() ),
+ painter.fillRect( context.layoutUnitToPixelX( parentOrigin.x() ),
+ context.layoutUnitToPixelY( parentOrigin.y() ),
+ context.layoutUnitToPixelX( getParent()->getWidth() ),
+ context.layoutUnitToPixelY( getParent()->getHeight() ),
style.background() );
- painter.drawText( context.tqlayoutUnitToPixelX( myPos.x() ),
- context.tqlayoutUnitToPixelY( myPos.y()+getBaseline() ),
+ painter.drawText( context.layoutUnitToPixelX( myPos.x() ),
+ context.layoutUnitToPixelY( myPos.y()+getBaseline() ),
text );
}
else {
@@ -226,17 +226,17 @@ void TextElement::draw( TQPainter& painter, const LuPixelRect& /*r*/,
// baseline==0 glyphs without yet another flag.
bl = -( getHeight()/2 + context.axisHeight( tstyle, factor ) );
}
- painter.drawText( context.tqlayoutUnitToPixelX( myPos.x() ),
- context.tqlayoutUnitToPixelY( myPos.y()+bl ),
+ painter.drawText( context.layoutUnitToPixelX( myPos.x() ),
+ context.layoutUnitToPixelY( myPos.y()+bl ),
TQString(ch) );
}
else {
painter.setPen( TQPen( context.getErrorColor(),
- context.tqlayoutUnitToPixelX( context.getLineWidth( factor ) ) ) );
- painter.drawRect( context.tqlayoutUnitToPixelX( myPos.x() ),
- context.tqlayoutUnitToPixelY( myPos.y() ),
- context.tqlayoutUnitToPixelX( getWidth() ),
- context.tqlayoutUnitToPixelY( getHeight() ) );
+ context.layoutUnitToPixelX( context.getLineWidth( factor ) ) ) );
+ painter.drawRect( context.layoutUnitToPixelX( myPos.x() ),
+ context.layoutUnitToPixelY( myPos.y() ),
+ context.layoutUnitToPixelX( getWidth() ),
+ context.layoutUnitToPixelY( getHeight() ) );
}
// }
@@ -244,10 +244,10 @@ void TextElement::draw( TQPainter& painter, const LuPixelRect& /*r*/,
//painter.setBrush(TQt::NoBrush);
// if ( isSymbol() ) {
// painter.setPen( TQt::red );
-// painter.drawRect( context.tqlayoutUnitToPixelX( myPos.x() ),
-// context.tqlayoutUnitToPixelX( myPos.y() ),
-// context.tqlayoutUnitToPixelX( getWidth() ),
-// context.tqlayoutUnitToPixelX( getHeight() ) );
+// painter.drawRect( context.layoutUnitToPixelX( myPos.x() ),
+// context.layoutUnitToPixelX( myPos.y() ),
+// context.layoutUnitToPixelX( getWidth() ),
+// context.layoutUnitToPixelX( getHeight() ) );
// painter.setPen(TQt::green);
// painter.drawLine(myPos.x(), myPos.y()+axis( context, tstyle ),
// myPos.x()+getWidth(), myPos.y()+axis( context, tstyle ));
@@ -527,7 +527,7 @@ void EmptyElement::calcSizes( const ContextStyle& context,
//kdDebug( DEBUGID ) << "TextElement::calcSizes size=" << mySize << endl;
TQFont font = context.getDefaultFont();
- font.setPointSizeFloat( context.tqlayoutUnitPtToPt( mySize ) );
+ font.setPointSizeFloat( context.layoutUnitPtToPt( mySize ) );
TQFontMetrics fm( font );
TQChar ch = 'A';
@@ -542,9 +542,9 @@ void EmptyElement::draw( TQPainter& painter, const LuPixelRect& /*r*/,
ContextStyle::TextStyle /*tstyle*/,
ContextStyle::IndexStyle /*istyle*/,
StyleAttributes& /*style*/ ,
- const LuPixelPoint& tqparentOrigin )
+ const LuPixelPoint& parentOrigin )
{
- LuPixelPoint myPos( tqparentOrigin.x()+getX(), tqparentOrigin.y()+getY() );
+ LuPixelPoint myPos( parentOrigin.x()+getX(), parentOrigin.y()+getY() );
/*
if ( !LuPixelRect( myPos.x(), myPos.y(), getWidth(), getHeight() ).intersects( r ) )
return;
@@ -552,10 +552,10 @@ void EmptyElement::draw( TQPainter& painter, const LuPixelRect& /*r*/,
if ( context.edit() ) {
painter.setPen( context.getHelpColor() );
- painter.drawLine( context.tqlayoutUnitToPixelX( myPos.x() ),
- context.tqlayoutUnitToPixelY( myPos.y() ),
- context.tqlayoutUnitToPixelX( myPos.x() ),
- context.tqlayoutUnitToPixelY( myPos.y()+getHeight() ) );
+ painter.drawLine( context.layoutUnitToPixelX( myPos.x() ),
+ context.layoutUnitToPixelY( myPos.y() ),
+ context.layoutUnitToPixelX( myPos.x() ),
+ context.layoutUnitToPixelY( myPos.y()+getHeight() ) );
}
}
@@ -156,21 +156,21 @@ void TextElement::calcSizes( const ContextStyle& context,
/**
* Draws the whole element including its tqchildren.
- * The `tqparentOrigin' is the point this element's tqparent starts.
- * We can use our tqparentPosition to get our own origin then.
+ * The `parentOrigin' is the point this element's tqparent starts.
+ * We can use our parentPosition to get our own origin then.
*/
void TextElement::draw( TQPainter& painter, const LuPixelRect& /*r*/,